@@ -12,8 +12,8 @@
       include "Zprivate2.f"
 
       save rspec, lossrspec, lossrspec2, respec
-      save rzspec,  zfspec, rtspec1, rtspec2, ertspec1, ertspec2
-      save erzspec,  rzfspec, rfspec, efspec, refspec
+      save rzspec,  zfspec, rtspec1, rtspec2, retspec1, retspec2
+      save rezspec,  rzfspec, rfspec, efspec, refspec
 
       integer id  ! input.  1 ==> aTrack is going out from
 c                                 outer boundery.
@@ -25,9 +25,10 @@ c                           3 ==> reached at inner boundery.
       record /coord/ angle
       record /coord/ tetafai
       
-      character*100 input
+      character*128 input
+      character*64 dirstr
       real sr, dr, tempr
-      integer i, j, icon
+      integer i, j, k, icon
       integer ansites
       save ansites
       integer iij, code
@@ -40,15 +41,27 @@ c                           3 ==> reached at inner boundery.
       real  de, Ek, f, molu
       real*8  cvh2den
       integer ldep
+c     integer ndummy
       integer binw
-      character*20 evid(nsites)
+      character*9 ptcl(3)
+      data ptcl/"Photons", "Electrons","Muons"/
+      character*9 ptcl2(3)
+      data ptcl2/"Electrons", "Muons","All"/
+      real power(3)
+      integer nstr
+      data power/2.,2.,1./
+      real  power2(3)
+      data power2/2.,1.,2./
+      character*128 title
+      character*96 evid(nsites)
       save evid
       real*8 cog, sumne,  obstimes
       character*2  kd(3)
       save obstimes
 
 c       keep this interface so that the difference between
-c       the one in ForTA/ is in the next line
+c       the one in ForTA/  and in FleshHist is in the next line
+c      1 for ForTA and 2 for FleshHist
 c     ***********************
       include "interface2.f"
 c     *********************
@@ -82,6 +95,9 @@ c         rspec (lateral):
             do j = 1, 3         ! g,e,mu
                call kwhisti(rspec(j, i),
      *              rmin, bin, nrbin,  b'00011' )
+               call kwhistai(rspec(j,i), 
+     *         "Lateral Dist. of "//ptcl(j),
+     *         "lat", "ptcls", .true., power(j), "r", "m.u")
             enddo
          enddo
       endif
@@ -95,9 +111,13 @@ c
             do j = 1, 3         !   e, mu, e+mu
                call kwhisti( lossrspec(j, i),
      *          rmin, bin, nrbin, b'00011')
+               call kwhistai(lossrspec(j, i), 
+     *         "dE/dx lateral dist. of "//ptcl2(j),
+     *         "dEdxLat", "GeV/(g/cm^2)", .true., power2(j),
+     *         "r", "m.u")
             enddo
 c                e+mu in the central region
-            call kwhisti( lossrspec2(i), 0., 0.1, 1,  b'00000')
+c            call kwhisti( lossrspec2(i), 0., 1.0, 20, b'00000')
          enddo   
       endif
 
@@ -107,13 +127,23 @@ c
          do i = 1, ansites
             do j= 1, 2
                call kwhisti2( respec(j, i),
-     *             0.01, 10., 13,  b'10011', 
-     *           500.e-6, 0.1,  30,  b'00001')
+     *             0.01, 0.2, 20,    b'00011', 
+     *             500.e-6, 0.1,    50,    b'00001')
+               call kwhiststep2(respec(j, i), 2)
+               call kwhistai2( respec(j, i),
+     *         "Energy Spec. of "//ptcl(j)//" at  diff. r",
+     *         "re", "ptcls", .true.,  1., 
+     *         "r", "m.u", "E", "GeV")
             enddo
-            
+c                 mu            
             call kwhisti2( respec(3, i),
-     *            0.05, 10.,  8, b'10001', 
-     *            0.1,  0.1,   21, b'00011' )
+     *            0.01, 0.2, 20       , b'00011', 
+     *            0.031627,  0.1,  38, b'00011' )
+            call kwhiststep2(respec(3, i), 2)
+            call kwhistai2( respec(3, i),
+     *      "Energy Spec. of mu at diff. r",
+     *      "re", "ptcls", .true.,  0.,
+     *      "r",  "m.u", "E", "GeV")
          enddo
       endif
 
@@ -122,12 +152,22 @@ c
          do i = 1, ansites
             do j= 1, 2
                call kwhisti2( rzspec(j, i),
-     *           0.01,   10., 11,  b'10011', 
-     *           0., 1.0, 20,  b'10000')
+     *           0.01,   0.2,  20,  b'00011', 
+     *           0.,     1.0,     20,  b'10000')
+               call kwhiststep2(rzspec(j, i), 2)
+               call kwhistai2( rzspec(j, i),
+     *         "Zenith angle dist. of "//ptcl(j)//" at diff. r",
+     *         "rz", "ptcls", .true., 0.,
+     *         "r", "m.u", "cosz", " ")
             enddo
             call kwhisti2(rzspec(3, i),
-     *           0.1, 10., 9, b'10011', 
-     *           0.,  1.0,   20,  b'10000' )  
+     *           0.01, 0.2, 20, b'00011', 
+     *           0.,  1.0,   20, b'10000' )  
+           call kwhiststep2(rzspec(3, i), 2)
+            call kwhistai2( rzspec(3, i),
+     *         "Zenith angle dist. of m  with diff. r",
+     *         "rz", "ptcls", .true., 0.,
+     *         "r", "m.u", "cosz", " ")
          enddo
       endif         
 
@@ -136,8 +176,14 @@ c
          do i = 1, ansites
             do j= 1, 3
                call kwhisti2( zfspec(j, i),
-     *              0.0,   1.0, 5,  b'10000', 
+     *              0.0,  1.0, 10,  b'10000', 
      *              -1.0, 1.0, 50,  b'10000')
+               call kwhiststep2(zfspec(j, i), 2)
+               call kwhistai2( zfspec(j, i),
+     *         "f=(wx,wy)*(x,y) spectrum of "//ptcl(j)//
+     *         " with diff. cosz", 
+     *         "zf", "ptcls", .true., 0.,
+     *         "cosz", " ", "f", " ")
             enddo
          enddo
       endif         
@@ -147,8 +193,13 @@ c
          do i = 1, ansites
             do j= 1, 3
                call kwhisti2( rfspec(j, i),
-     *              1.0,  0.25, 12,  b'00011', 
-     *              -1.0, 1.0, 50,    b'10000')
+     *                0.01,  0.2, 20,  b'00011', 
+     *               -1.0,  1.0, 50,   b'10000')
+               call kwhiststep2(rfspec(j, i), 2)
+               call kwhistai2( rfspec(j, i),
+     *         "f spectrum of "//ptcl(j)//" with diff. r",
+     *         "rf", "ptcls", .true., 0.,
+     *          "r", "m.u", "f", " ")
             enddo
          enddo
       endif         
@@ -160,6 +211,11 @@ c
                call kwhisti2( efspec(j, i),
      *              500.e-6,  0.2, 20,  b'00001', 
      *              -1.0,     1.0, 50,  b'10000')
+               call kwhiststep2(efspec(j, i), 2)
+               call kwhistai2( efspec(j, i),
+     *         "f spectrum of "//ptcl(j)//" with diff. E",
+     *         "ef", "ptcls",.true., 0.,
+     *         "E", "GeV", "f", " ")
             enddo
          enddo
       endif         
@@ -168,57 +224,97 @@ c
          do i = 1, ansites
             do j = 1, 3
                call kwhisti2( rtspec1(j, i),
-     *              1.0, 10., 9, b'10011', 
-     *              10.0,  0.1,  72, b'00011'  )
+     *              1.0, 0.2,  10,   b'00011', 
+     *              10.,  0.1, 55, b'00011'  )
+               call kwhiststep2(rtspec1(j, i), 2)
+               call kwhistai2( rtspec1(j, i),
+     *         "Arrival time dist. of "//ptcl(j)//" at diff. r",
+     *         "rt", "ptcls", .true., 0.,
+     *         "r", "m.u", "time", "ns")
+
                call kwhisti2( rtspec2(j, i),
-     *             0., 1.0, 5, b'10000', 
-     *             0., 1.0, 200, b'00000' )
+     *             0.,  1.0, 10,  b'10000', 
+     *             0., 0.25, 300, b'00000' )
+               call kwhiststep2(rtspec2(j, i), 2)
+               call kwhistai2( rtspec2(j, i),
+     *         "Arrival time dist. of "//ptcl(j)//" at diff. r",
+     *         "rt", "ptcls", .true., 0.,
+     *         "r", "m.u", "time", "ns")
             enddo
          enddo
       endif
 
-
-      
-      if(tkertspec)  then
+      if(tkretspec)  then
          do i = 1, ansites
             do j = 1, 2
 c                  g,e
-               call kwhisti3(ertspec1(j, i), 
-     *          500.e-6, 0.3333333, 13, b'00001',
-     *          1.0,  0.3333333,  8,  b'00011',
-     *          10.0, 0.1,  72,    b'00011' )
+               call kwhisti3(retspec1(j, i), 
+     *          1.0,     0.2,  10,    b'00011',
+     *          500.e-6, 0.25, 15,    b'01001',
+     *          10.0, 0.1,  55,      b'00011' )
+               call kwhiststep3(retspec1(j, i), 2, 2)
+               call kwhistai3(retspec1(j, i), 
+     *         "Arrival time dist. of "//ptcl(j)//" with diff. r&E",
+     *         "ret", "ptcls", .true., 0.,
+     *         "r", "m.u", "E", "GeV", "Time", "ns")
 
-               call kwhisti3(ertspec2(j, i), 
-     *          500.e-6, 0.3333333, 13,  b'0001',
-     *          0.0,  1.0,   5,  b'10000',
-     *          0.0,  2.0,    50,  b'00000' )
+               call kwhisti3(retspec2(j, i), 
+     *          0.0,  1.0,     10,   b'10000',
+     *          500.e-6, 0.25, 12,  b'01001',
+     *          0.0,  0.25,   200,  b'00000' )
+               call kwhiststep3(retspec2(j, i), 2,2)
+               call kwhistai3(retspec2(j, i), 
+     *         "Arrival time dist. of "//ptcl(j)//" with diff. r&E",
+     *         "ret2", "ptcls", .true., 0.,
+     *         "r", "m.u", "E", "GeV", "Time", "ns")
             enddo
 c               mu
-            call kwhisti3(ertspec1(3, i), 
-     *           100.e-3, 0.3333333, 7, b'00011',
-     *           1.0,  0.3333333,   8, b'00011',
-     *           10.0, 0.1,  72,        b'00011' )
-            call kwhisti3(ertspec2(3, i), 
-     *           100.e-3, 0.3333333, 7, b'00011',
-     *           0.0,  1.0,     5,    b'10000',
-     *           0.0,  2.0,     50,     b'00000' )
+            call kwhisti3(retspec1(3, i), 
+     *           1.0,   0.2,    10,       b'00011',
+     *           100.e-3, 0.25, 10,       b'01011',
+     *           10.0,    0.1,  72,       b'00011' )
+            call kwhiststep3(retspec1(3, i),  2, 2)
+            call kwhistai3(retspec1(3, i), 
+     *         "Arrival time dist. of "//ptcl(3)//" with diff. r&E",
+     *         "ret", "ptcls", .true., 0.,
+     *         "r", "m.u", "E", "GeV", "Time", "ns")
+
+
+            call kwhisti3(retspec2(3, i), 
+     *           0.0,  1.0,  10,    b'10000',
+     *           100.e-3,    0.25, 10,   b'01011',
+     *           0.0,  0.25,    200,     b'00000' )
+            call kwhiststep3(retspec2(3, i), 2,2)
+            call kwhistai3(retspec2(3, i), 
+     *         "Arrival time dist. of "//ptcl(3)//" with diff. r&E",
+     *         "ret2", "ptcls", .true., 0.,
+     *         "r", "m.u", "E", "GeV", "Time", "ns")
          enddo
       endif
 
 
-
-      if(tkerzspec) then
+      if(tkrezspec) then
          do i = 1, ansites
             do j = 1, 2
-               call kwhisti3(erzspec(j, i), 
-     *         500.e-6, 0.3333333, 7, b'00001',
-     *         0.1, 0.3333333,  10,   b'00011',
-     *         0.0, 1.0,       20,    b'10000')
+               call kwhisti3( rezspec(j, i), 
+     *         0.1,   0.2,  15,     b'00011',
+     *         500.e-6, 0.25, 14,   b'01001', 
+     *         0.0, 1.0,   20,    b'10000')
+               call kwhiststep3(rezspec(j, i), 3,2)
+               call kwhistai3(rezspec(j, i), 
+     *         "cos zenith dist. of "//ptcl(j)//" with diff. r&E",
+     *         "rez", "ptcls", .true., 0.,
+     *         "r", "m.u", "E", "GeV", "cosz", " ") 
             enddo
-            call kwhisti3(erzspec(3, i), 
-     *         100.e-3, 0.3333333, 7, b'00011',
-     *         0.1, 0.3333333,  10,   b'00011',
-     *         0.0, 1.0,        20,   b'10000')
+            call kwhisti3(rezspec(3, i), 
+     *         0.1,  0.2,   15,   b'00011',
+     *         100.e-3, 0.25, 10, b'01011', 
+     *         0.0, 1.0,     20,   b'10000')
+            call kwhiststep3(rezspec(3, i), 3,2)
+            call kwhistai3(rezspec(3, i), 
+     *         "cos zenith dist. of "//ptcl(3)//" with diff. r&E",
+     *         "rez", "ptcls", .true., 0.,
+     *         "r", "m.u", "E", "GeV", "cosz", " ") 
          enddo
       endif
 
@@ -228,21 +324,40 @@ c               mu
          do i = 1, ansites
             do j = 1, 3
                call kwhisti3(rzfspec(j, i), 
-     *         0.1, 0.3333333,  10,   b'00011',
-     *         0.0, 1.0,         5,   b'10000',  
+     *         0.1, 0.2,        15,   b'00011',
+     *         0.0, 1.0,        10,   b'10000',  
      *         -1.0, 1.0,       20,   b'10000')
+               call kwhiststep3(rzfspec(j, i), 3,2)
+               call kwhistai3(rzfspec(j, i), 
+     *         "f spectrum of "//ptcl(j)//" with diff r&cosz",
+     *         "rzf", "ptcls", .true., 0.,
+     *         "r", "m.u", "cosz", " ", "f", " ")
             enddo
          enddo
       endif
 
       if(tkrefspec) then
          do i = 1, ansites
-            do j = 1, 3
-               call kwhisti3(refspec(j, i), 
-     *         0.1, 10.,     10,   b'10011',
-     *         500.e-6, 0.2,   20,   b'00001',  
-     *         -1.0, 1.0,      20,   b'10000')
+            do j = 1, 2
+               call kwhisti3( refspec(j, i), 
+     *         0.1,  0.2,      15,   b'00011',
+     *         500.e-6, 0.25,  16,    b'01001',  
+     *         -1.0, 1.0,     20,   b'10000')
+               call kwhiststep3(refspec(j, i), 3,3)
+               call kwhistai3(refspec(j, i),
+     *         "f spectrum of "//ptcl(j)//" with diff. r&E",
+     *         "ref", "ptcls", .true., 0.,
+     *         "r", "m.u", "E", "GeV", "f", " ")
             enddo
+            call kwhisti3(refspec(3, i), 
+     *       0.1, 0.2,      15,    b'00011',
+     *       100.e-3,  0.25, 10,    b'01001',  
+     *        -1.0, 1.0,     20,   b'10000')
+            call kwhiststep3(refspec(3, i), 3,2)
+            call kwhistai3(refspec(3, i),
+     *         "f spectrum of "//ptcl(3)//" with diff. r&E",
+     *         "ref", "ptcls", .true., 0.,
+     *         "r", "m.u", "E", "GeV", "f", " ")
          enddo
       endif
 
@@ -279,7 +394,7 @@ c
             do j = 1, 3
                call kwhistc(lossrspec(j,i))
             enddo
-            call kwhistc(lossrspec2(i))
+c            call kwhistc(lossrspec2(i))
          enddo
       endif
 
@@ -332,21 +447,21 @@ c
       endif
 
          
-      if(tkertspec) then
+      if(tkretspec) then
          do i = 1, ansites
             do j = 1, 3
-               call kwhistc3(ertspec1(j,i))
-               call kwhistc3(ertspec2(j,i))
+               call kwhistc3(retspec1(j,i))
+               call kwhistc3(retspec2(j,i))
             enddo
          enddo
       endif
 
 
 
-      if(tkerzspec) then
+      if(tkrezspec) then
          do i = 1, ansites
             do j = 1, 3
-               call kwhistc3(erzspec(j,i))
+               call kwhistc3(rezspec(j,i))
             enddo
          enddo
       endif
@@ -463,6 +578,7 @@ c                     see if this is > K.E
                Eloss = Ek
                dist = Eloss/dedt
             endif
+            Eloss = Eloss*10.       !  GeV/(g/cm2)
             SumEloss(ldep)=SumEloss(ldep) + Eloss
          endif
 c            ------------------
@@ -519,7 +635,7 @@ cc                        tempr = rbin(ic)/ObsSites(j).mu
 cc                     endif
 c                       by   all charged particles
                      call kwhist(lossrspec(3,i), tempr, de)
-                     call kwhist(lossrspec2(i), tempr, de)
+c                     call kwhist(lossrspec2(i), tempr, de)
                      if( aTrack.p.code .eq.  kelec ) then
 c                          by electrons
                         call kwhist(lossrspec(1,i), tempr, de)
@@ -581,15 +697,15 @@ c                  re spectrum
      *              sngl( aTrack.t ), 1.0)
                endif
 
-               if(tkertspec .and. code .le. 3) then
-                  call kwhist3( ertspec1(code, i), Ek, sr,
+               if(tkretspec .and. code .le. 3) then
+                  call kwhist3( retspec1(code, i), sr,  Ek, 
      *                 sngl( aTrack.t ), 1.0)
-                  call kwhist3( ertspec2(code, i), Ek, sr,
+                  call kwhist3( retspec2(code, i), sr,  Ek, 
      *                 sngl( aTrack.t ), 1.0)
                endif
 
-               if( tkerzspec .and. code .le. 3 ) then
-                  call kwhist3( erzspec(code,i), Ek, sr,
+               if( tkrezspec .and. code .le. 3 ) then
+                  call kwhist3( rezspec(code,i), sr, Ek, 
      *              sngl(wz),  1.0 ) 
                endif
 
@@ -609,9 +725,9 @@ c                  re spectrum
  100     continue
       endif
       return
-c     ********************
+c     **************
       entry xEnEvent
-
+c     **************
 
       if(ObserveAS) then
          cog = 0.
@@ -625,7 +741,8 @@ c     ********************
          do i = 1, NoOfASSites 
             if(fnoB .ge. 0) then
                write(fnoB, '( i4, i3, i5,
-     *          g12.4, f5.2, f5.2, g12.4, f7.1, 3g10.3, f7.0)')
+     *          1pE11.3, 0pf5.2, f5.2, 1pE11.3, 0pf7.1,
+     *          1p3E11.3, 0pf7.0)')
      *          EventNo, i,
      *          int( ASDepthList(i)*0.1 ),  
      *          sngl(ASObsSites(i).esize), sngl(ASObsSites(i).age),
@@ -633,7 +750,8 @@ c     ********************
      *          sngl(ASObsSites(i).mu), Ng(i), Ne(i), Nmu(i), cog
             else
                write(*, '( i4, i3, i5,
-     *          g12.4, f5.2, f5.2, g12.4, f7.1, 3g10.3, f7.0)')
+     *          1pE11.3, 0pf5.2, f5.2, 1pE11.3, 0pf7.1,
+     *          1p3E11.3, 0pf7.0)')
      *          EventNo, i,
      *          int( ASDepthList(i)*0.1 ),  
      *          sngl(ASObsSites(i).esize), sngl(ASObsSites(i).age),
@@ -649,18 +767,24 @@ c     ********************
       endif
 
       do i = 1, ansites
-         write(evid(i), '(" # ",i4, i3, f5.2, f5.2)') 
-     *   EventNo, histdep(i),
-     *   ASObsSites(histdep(i)).age,
-     *   ASDepthList(histdep(i))*0.1/cog
+         j=histdep(i)
+         write(evid(i), 
+     *   '(i3, i5,  f5.2, f5.2,
+     *   i5,  i4)')
+     *   histdep(i), int( ASDepthList(j)*0.1 ),  
+     *   ASObsSites(j).age, ASDepthList(j)*0.1/cog,
+     *   int(ASObsSites(i).mu), int(cog)
       enddo
 
 
       if( tklat ) then
          do j = 1, 3
             do i = 1, ansites
+               k = histdep(i)
                call kwhists( rspec(j,i), 0. ) ! 0. means area norm.
-               call kwhistid(rspec(j,i), evid(i)//kd(j)//' lat')
+               call kwhistev(rspec(j,i), EventNo)
+               call kwhistid(rspec(j,i), evid(i))
+               call kwhistdir(rspec(j,i), ptcl(j)//"/")
                call kwhistp( rspec(j,i),  fno)
             enddo
          enddo
@@ -670,26 +794,20 @@ c     ********************
          do j = 1, 3
             do i = 1, ansites
                call kwhists( lossrspec(j,i), 0. ) ! area norm
+               call kwhistev(lossrspec(j,i), EventNo)
+               call kwhistid( lossrspec(j, i), evid(i))
+               call kwhistdir( lossrspec(j, i), ptcl2(j)//"/")
+               call kwhistp( lossrspec(j, i), fno)
             enddo
          enddo
        
-         do i = 1, ansites
-            call kwhistid( lossrspec(1, i), evid(i)//' e'//' dEr')
-            call kwhistp( lossrspec(1, i), fno)
-         enddo
-         do i = 1, ansites
-            call kwhistid( lossrspec(2, i), evid(i)//' m'//' dEr')
-            call kwhistp( lossrspec(2, i),  fno)
-         enddo
-         do i = 1, ansites
-            call kwhistid( lossrspec(3, i), evid(i)//' a'//' dEr')
-            call kwhistp( lossrspec(3, i), fno)
-         enddo
-         do i = 1, ansites
-            call kwhists( lossrspec2(i), 0. )
-            call kwhistid( lossrspec2(i), evid(i)//' a'//' dEr2')
-            call kwhistp( lossrspec2(i), fno)
-         enddo
+
+c         do i = 1, ansites
+c            call kwhists( lossrspec2(i), 0. )
+c            call kwhistev(lossrspec2d3(j,i), EventNo)
+c            call kwhistid( lossrspec2(i), evid(i)//' a'//' dEr2')
+c            call kwhistp( lossrspec2(i), fno)
+c         enddo
       endif
  120  continue
       
@@ -697,7 +815,13 @@ c     ********************
          do j = 1, 3
             do i = 1, ansites
                call kwhists2( respec(j, i), 0. )
-               call kwhistid2( respec(j, i), evid(i)//kd(j)//' re')
+               call kwhistev2( respec(j,i), EventNo)
+               call kwhistid2( respec(j, i), evid(i))
+               k=histdep(i)
+               write(dirstr,'(a,"/d",i4, "/")') 
+     *              ptcl(j), int( ASDepthList(k)*0.1 )  
+               call kseblk(dirstr, "|", nstr)
+               call kwhistdir2(respec(j, i),  dirstr)
                call kwhistp2( respec(j, i),  fno)
             enddo
          enddo
@@ -708,7 +832,12 @@ c     ********************
          do j = 1, 3
             do i = 1, ansites
                call kwhists2( rzspec(j, i), 0.)
-               call kwhistid2( rzspec(j, i),  evid(i)//kd(j)//' rz')
+               call kwhistid2( rzspec(j, i),  evid(i))
+               k=histdep(i)
+               write(dirstr,'(a,"/d",i4, "/")') 
+     *              ptcl(j), int( ASDepthList(k)*0.1 )  
+               call kseblk(dirstr, "|", nstr)
+               call kwhistdir2( rzspec(j, i),  dirstr)
                call kwhistp2( rzspec(j, i),  fno)
             enddo
          enddo
@@ -719,7 +848,12 @@ c     ********************
          do j = 1, 3
             do i = 1, ansites
                call kwhists2( zfspec(j, i), 0.)
-               call kwhistid2( zfspec(j, i), evid(i)//kd(j)//' zf')
+               call kwhistid2( zfspec(j, i), evid(i) )
+               k=histdep(i)
+               write(dirstr,'(a,"/d",i4, "/")') 
+     *              ptcl(j), int( ASDepthList(k)*0.1 )  
+               call kseblk(dirstr, "|", nstr)
+               call kwhistdir2(  zfspec(j, i),  dirstr)
                call kwhistp2( zfspec(j, i),  fno)
             enddo
          enddo
@@ -731,7 +865,12 @@ c     ********************
          do j = 1, 3
             do i = 1, ansites
                call kwhists2( rfspec(j, i), 0.)
-               call kwhistid2( rfspec(j, i), evid(i)//kd(j)//' rf')
+               call kwhistid2( rfspec(j, i), evid(i))
+               k=histdep(i)
+               write(dirstr,'(a,"/d",i4, "/")') 
+     *              ptcl(j), int( ASDepthList(k)*0.1 )  
+               call kseblk(dirstr, "|", nstr)
+               call kwhistdir2(rfspec(j, i),  dirstr)
                call kwhistp2( rfspec(j, i),  fno)
             enddo
          enddo
@@ -742,7 +881,13 @@ c     ********************
          do j = 1, 3
             do i = 1, ansites
                call kwhists2( efspec(j, i), 0.)
-               call kwhistid2( efspec(j, i), evid(i)//kd(j)//' ef')
+               call kwhistev2(efspec(j,i), EventNo)
+               call kwhistid2( efspec(j, i), evid(i))
+               k=histdep(i)
+               write(dirstr,'(a,"/d",i4, "/")') 
+     *              ptcl(j), int( ASDepthList(k)*0.1 )  
+               call kseblk(dirstr, "|", nstr)
+               call kwhistdir2(efspec(j, i),  dirstr)
                call kwhistp2( efspec(j, i),  fno)
             enddo
          enddo
@@ -753,44 +898,74 @@ c     ********************
          do j = 1, 3
             do i = 1, ansites
                call kwhists2( rtspec1(j,i), 0.)
-               call kwhistid2( rtspec1(j,i), evid(i)//kd(j)//' rt')
+               call kwhistev2( rtspec1(j,i), EventNo)
+               call kwhistid2( rtspec1(j,i), evid(i))
+               k=histdep(i)
+               write(dirstr,'(a,"/d",i4, "/")') 
+     *              ptcl(j), int( ASDepthList(k)*0.1 )  
+               call kseblk(dirstr, "|", nstr)
+               call kwhistdir2(rtspec1(j,i),  dirstr)
                call kwhistp2( rtspec1(j,i),  fno)
             enddo
          enddo
          do j = 1, 3
             do i = 1, ansites
                call kwhists2( rtspec2(j,i), 0.)
-               call kwhistid2( rtspec2(j,i), evid(i)//kd(j)//' rt2')
+               call kwhistev2(rtspec2(j,i), EventNo)
+               call kwhistid2( rtspec2(j,i), evid(i))
+               k=histdep(i)
+               write(dirstr,'(a,"/d",i4, "/")') 
+     *              ptcl(j), int( ASDepthList(k)*0.1 )  
+               call kseblk(dirstr, "|", nstr)
+               call kwhistdir2(rtspec2(j,i),  dirstr)
                call kwhistp2( rtspec2(j,i),  fno)
             enddo
          enddo
       endif
 
 
-      if(tkertspec ) then
+      if(tkretspec ) then
          do j = 1, 3
             do  i = 1, ansites
-               call kwhists3( ertspec1(j, i), 0.)
-               call kwhistid3( ertspec1(j, i), evid(i)//kd(j)//' ert')
-               call kwhistp3( ertspec1(j, i), fno)
+               call kwhists3( retspec1(j, i), 0.)
+               call kwhistev3(retspec1(j,i), EventNo)
+               call kwhistid3( retspec1(j, i), evid(i))
+               k=histdep(i)
+               write(dirstr,'(a,"/d",i4,"/")' ) 
+     *           ptcl(j), int( ASDepthList(k)*0.1 )
+               call kseblk(dirstr, "|", nstr)
+               call kwhistdir3( retspec1(j, i), dirstr)
+               call kwhistp3( retspec1(j, i), fno)
             enddo
          enddo
          do j = 1, 3
             do  i = 1, ansites
-               call kwhists3( ertspec2(j, i), 0.)
-               call kwhistid3( ertspec2(j, i), evid(i)//kd(j)//' ert2')
-               call kwhistp3( ertspec2(j, i), fno)
+               call kwhists3( retspec2(j, i), 0.)
+               call kwhistev3(retspec2(j,i), EventNo)
+               call kwhistid3( retspec2(j, i), evid(i))
+               k=histdep(i)
+               write(dirstr,'(a,"/d",i4, "/")' ) 
+     *           ptcl(j), int( ASDepthList(k)*0.1 )
+               call kseblk(dirstr, "|", nstr)
+               call kwhistdir3(retspec2(j, i), dirstr)
+               call kwhistp3( retspec2(j, i), fno)
             enddo
          enddo
       endif
 
 
-      if( tkerzspec ) then
+      if( tkrezspec ) then
          do j = 1, 3
             do  i = 1, ansites
-               call kwhists3( erzspec(j, i), 0.)
-               call kwhistid3( erzspec(j, i), evid(i)//kd(j)//' erz')
-               call kwhistp3( erzspec(j, i),  fno)
+               call kwhists3( rezspec(j, i), 0.)
+               call kwhistev3(rezspec(j,i), EventNo)
+               call kwhistid3( rezspec(j, i), evid(i))
+               k=histdep(i)
+               write(dirstr,'(a,"/d",i4,"/")' ) 
+     *           ptcl(j), int( ASDepthList(k)*0.1 )
+               call kseblk(dirstr, "|", nstr)
+               call kwhistdir3(rezspec(j, i),  dirstr)
+               call kwhistp3( rezspec(j, i),  fno)
             enddo
          enddo
       endif
@@ -800,7 +975,13 @@ c     ********************
          do j = 1, 3
             do  i = 1, ansites
                call kwhists3( rzfspec(j, i), 0.)
-               call kwhistid3( rzfspec(j, i), evid(i)//kd(j)//' rzf')
+               call kwhistev3(rzfspec(j,i), EventNo)
+               call kwhistid3( rzfspec(j, i), evid(i))
+               k=histdep(i)
+               write(dirstr,'(a,"/d",i4,"/")' ) 
+     *           ptcl(j), int( ASDepthList(k)*0.1 )
+               call kseblk(dirstr, "|", nstr)
+               call kwhistdir3(rzfspec(j, i),  dirstr)
                call kwhistp3( rzfspec(j, i),  fno)
             enddo
          enddo
@@ -811,11 +992,15 @@ c     ********************
          do j = 1, 3
             do  i = 1, ansites
                call kwhists3( refspec(j, i), 0.)
-               call kwhistid3( refspec(j, i), evid(i)//kd(j)//' ref')
+               call kwhistev3(refspec(j,i), EventNo)
+               call kwhistid3( refspec(j, i), evid(i))
+               k=histdep(i)
+               write(dirstr,'(a,"/d",i4, "/")' ) 
+     *           ptcl(j), int( ASDepthList(k)*0.1 )
+               call kseblk(dirstr, "|", nstr)
+               call kwhistdir3( refspec(j, i),  dirstr)
                call kwhistp3( refspec(j, i),  fno)
             enddo
          enddo
       endif
-
-
       end
