@@ -184,13 +184,19 @@ c              stack current ptcl
          call cpush(MovedTrack)
       elseif(MoveStat .eq. ToInteract ) then
          if(Zfirst.pos.depth .eq. 0.) then
-            if(  (MovedTrack.p.code .ge. kpion  .and. 
-     *            MovedTrack.p.code .le. knuc ) .or.
-     *         MovedTrack.p.code .eq. kgnuc ) then
+c            if(  (MovedTrack.p.code .ge. kpion  .and. 
+c     *            MovedTrack.p.code .le. knuc ) .or.
+c     *         MovedTrack.p.code .eq. kgnuc ) then
+c            from  v.7.10
+            if(  (IncidentCopy.p.code .ge. kpion  .and. 
+     *            IncidentCopy.p.code .le. knuc ) .or.
+     *            IncidentCopy.p.code .eq. kgnuc ) then
+
 c
 c                   from  v6.31 1ry is judged by Stack_pos
 c                  (even if this is not used, almost no problem)
 c                     ! if no stack, the particle should be 1ry (since Zfirst=0)
+
                if( Stack_pos .eq. 0 .and.
      *             IntInfArray(ProcessNo).process .eq. 'coll') then
                   reset = .true.
